"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const styles_1 = require("../styles");
module.exports = {
    meta: {
        docs: {
            description: "Disallow parsing errors in `<style>`",
            category: "recommended",
            default: "warn",
            url: "https://future-architect.github.io/eslint-plugin-vue-scoped-css/rules/no-parsing-error.html",
        },
        fixable: null,
        messages: {},
        schema: [],
        type: "problem",
    },
    create(context) {
        const styles = styles_1.getStyleContexts(context).filter(style => !style.invalid);
        if (!styles.length) {
            return {};
        }
        const reporter = styles_1.getCommentDirectivesReporter(context);
        function report(node) {
            reporter.report({
                node,
                loc: node.loc.start,
                message: "Parsing error: {{message}}.",
                data: {
                    message: node.message.endsWith(".")
                        ? node.message.slice(0, -1)
                        : node.message,
                },
            });
        }
        return {
            "Program:exit"() {
                var _a;
                for (const style of styles) {
                    for (const node of ((_a = style.cssNode) === null || _a === void 0 ? void 0 : _a.errors) || []) {
                        report(node);
                    }
                }
            },
        };
    },
};
